#include <ncurses.h>

#ifndef _ENGINE_H_
#define _ENGINE_H_

/* * *
 * This struct represent the board that the game will run in.
 * * */
typedef struct Board {
	WINDOW* win;			/* The window that contains this board. */
	unsigned int yMax;	/* The maximum vertical value of the window. */ 
	unsigned int xMax;	/* The maximum horizontal value of the window. */ 
	unsigned int yLoc;	/* The starting vertical coordinate of the board */
	unsigned int xLoc;	/* The starting horizontal coordinate of the board */
	unsigned int height;  /* The height of the board. */
	unsigned int width;	/* The width of the board. */ 
} Board;


#include "Snake.h"
#include "Food.h"

/* * *
 * Create a board with border with height according to the maximum values 
 * of the standard screen.
 * * */
void Board_Create(Board* board);

/* * *
 * Draw the snake and the food inside the board passed in.
 * * */
void Engine_Draw(Board* board, Snake_t* snake, Food_t* food, const int* level, const unsigned short* score, unsigned int* snakeLen);

/* * *
 * <<< SNAKE GAME ENGINE >>>
 * Run snake starting with snake_length inside board passed in.
 * Change snake direction according to user's input.
 * Extend snake_length by one when snake eat one food.
 * Stop when snake have collision or when snake is out of bound.
 * * */
void Engine_Run(Board* board, Snake_t* snake, unsigned int* snake_length);

#endif
